#
# spec file for package coq
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012-2018 Peter Trommler, peter.trommler at ohm-hochschule.de
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without ide

Name:           coq
Version:        8.13.2
Release:        bp154.1.44
Summary:        Proof Assistant based on the Calculus of Inductive Constructions
License:        LGPL-2.1-only
Group:          Productivity/Scientific/Math
URL:            https://coq.inria.fr/
Source:         https://github.com/coq/coq/archive/V%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        coq.desktop
Source2:        coq.xml
Source50:       coq-refman-%{version}.tar.xz
Source51:       coq-stdlib-%{version}.tar.xz
Source100:      %{name}-rpmlintrc
BuildRequires:  desktop-file-utils
BuildRequires:  make >= 3.81
BuildRequires:  ocaml >= 4.05.0
BuildRequires:  ocaml-camlp5-devel >= 5.08
BuildRequires:  ocamlfind(findlib)
BuildRequires:  ocamlfind(zarith)
%if %{with ide}
BuildRequires:  update-desktop-files
BuildRequires:  ocamlfind(lablgtk3)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
%endif

%description
Proof assistant which allows to handle calculus assertions, check mechanically
proofs of these assertions, helps to find formal proofs and extracts a certified
program from the constructive proof of its formal specification.

This package contains shared files and the command line interface.
For a graphical interface install %{name}-ide.

%package ide
Summary:        IDE for The Coq Proof Assistant
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}-%{release}

%description ide
The Coq Integrated Development Interface is a graphical interface for the Coq proof assistant.

%package devel
Summary:        Development files for coq
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml >= 4.05.0
Requires:       ocamlfind(findlib)

%description devel
This package contains development files for Coq.

%package doc
Summary:        Documentation for coq
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
HTML reference manual for Coq and full documentation of the standard library.

%prep
%setup -q -a 50 -a 51
# META for ocamlfind doesn't contain a version, so configure.ml fails. We patch that.
sed -i 's/v, _ = tryrun camlexec.find \["query"; "-format"; "%v"; "lablgtk3"\]/v = "%{pkg_version ocamlfind(lablgtk3)}"/' \
    configure.ml

%build
export CFLAGS='%{optflags}'
# TODO: Add -with-doc yes
./configure                \
   -bindir %{_bindir}      \
   -libdir %{_libdir}/coq  \
   -mandir %{_mandir}      \
   -datadir %{_datadir}/%{name} \
   -docdir %{_docdir}/%{name} \
   -configdir %{_sysconfdir}/xdg/%{name} \
   -coqdocdir %{_datadir}/texmf/tex/latex/misc \
%if %{with ide}
   -coqide opt \
%else
   -coqide no \
%endif
   -native-compiler yes \
   -natdynlink yes \
   -browser "xdg-open %s"

make %{?_smp_mflags} world

%install
%if %{with ide}
# Fixup dependencies before we install. Some are apparently not detected.
sed -i 's#^ide/ide_MLLIB_DEPENDENCIES:=.*$#& ide/configwin_types ide/protocol/richpp#' \
    .mllibfiles.d
%endif

make COQINSTALLPREFIX=%{buildroot} install

%if %{with ide}
%suse_update_desktop_file -i %{SOURCE1}
install -D -m 644 %{SOURCE1} %{buildroot}%{_datadir}/applications/coq.desktop
install -D -m 644 %{SOURCE2} %{buildroot}%{_datadir}/mime/packages/coq.xml
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
ln -s %{_datadir}/coq/coq.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/coq.png
%else
rm %{buildroot}%{_bindir}/coqidetop{,.opt} %{buildroot}%{_mandir}/man1/coqide.1
%endif

# Sometimes we get identical x and x.opt files, replace by symlink x -> x.opt.
for bin in %{buildroot}%{_bindir}/*.opt
do
    if [ -f ${bin%.opt} ] && diff $bin ${bin%.opt}
    then
        rm ${bin%.opt}
        ln -s ${bin#%{buildroot}} ${bin%.opt}
    fi
done

# Fix executable bit and shebangs, preferring python3.
# (https://www.python.org/dev/peps/pep-0394/#for-python-runtime-distributors)
chmod -x %{buildroot}%{_libdir}/%{name}/tools/TimeFileMaker.py
sed -i '1s|^#!/usr/bin/env *|#!/usr/bin/|;1s|^#!/usr/bin/python$|#!/usr/bin/python3|' \
    %{buildroot}%{_libdir}/%{name}/tools/make-{one-time-file,both-{time,single-timing}-files}.py

# Remove superfluous man page.
rm %{buildroot}%{_mandir}/man1/coqtop.byte.1

# Remove unneeded empty *.vos files.
find %{buildroot}%{_libdir}/coq -empty -name '*.vos' -delete

# Build lists of runtime and devel files by ending.
# Compiled theories and shared objects are needed at runtime.
find %{buildroot}%{_libdir}/coq/{plugins,theories} -type d | \
    sed "s|%{buildroot}|%%dir |g" >runtime.list
find %{buildroot}%{_libdir}/coq -name '*.cmxs' \
                -or -name '*.so' \
                -or -name '*.vo' | sed "s|%{buildroot}||g" >>runtime.list

# Object files, static libraries and import definitions are only needed for development.
# For now, we also put the standard library Coq sources here, since the runtime
# package contains the HTML documentation for the standard library.
find %{buildroot}%{_libdir}/coq -type d | sed "s|%{buildroot}|%%dir |g" >devel.list
find %{buildroot}%{_libdir}/coq -name '*.a' \
                -or -name '*.cma' \
                -or -name '*.cmi' \
                -or -name '*.cmx' \
                -or -name '*.cmxa' \
                -or -name '*.glob' \
                -or -name '*.o' \
                -or -name '*.v' | sed "s|%{buildroot}||g" >>devel.list

# Until we can build it, we fetch the documentation from the official website:
# svn export https://github.com/coq/doc/trunk/V%{version}/refman
# svn export https://github.com/coq/doc/trunk/V%{version}/stdlib
# tar --sort=name --owner=0 --group=0 --mtime="@$(stat -c %%Y refman/index.html)" \
#     --pax-option=exthdr.name=%d/PaxHeaders/%f,delete=atime,delete=ctime \
#     -cJf coq-refman-%{version}.tar.xz refman
# tar --sort=name --owner=0 --group=0 --mtime="@$(stat -c %%Y stdlib/index.html)" \
#     --pax-option=exthdr.name=%d/PaxHeaders/%f,delete=atime,delete=ctime \
#     -cJf coq-stdlib-%{version}.tar.xz stdlib

# Drop some CSS files and headers in stdlib documentation, add some margin directly.
find stdlib/ -name '*.html' -exec sed -i '
s#//coq.inria.fr/sites/all/themes/coq/coqdoc.css#/usr/lib64/coq/tools/coqdoc/coqdoc.css#
/<link type="text\/css" rel="stylesheet" media="all" href="\/\/coq.inria.fr\/.*.css" \/>/d
/<div id="container">/s/>/ style="margin:1em;">/
/^  <div id="headertop">$/,/^  <\/div>$/d
/^  <div id="header">$/,/^  <\/div>$/d
' {} +
cp -r refman stdlib %{buildroot}%{_docdir}/coq
rm -r %{buildroot}%{_docdir}/coq/refman/{.doctrees,_sources}

%files -f runtime.list
%license LICENSE CREDITS
%doc README.md

%{_bindir}/coq-tex
%{_bindir}/coq_makefile
%{_bindir}/coqc
%{_bindir}/coqchk
%{_bindir}/coqdep
%{_bindir}/coqdoc
%{_bindir}/coqpp
%{_bindir}/coqproofworker.opt
%{_bindir}/coqqueryworker.opt
%{_bindir}/coqtacticworker.opt
%{_bindir}/coqtop
%{_bindir}/coqtop.opt
%{_bindir}/coqwc
%{_bindir}/coqworkmgr
%{_bindir}/ocamllibdep
%{_bindir}/votour

%dir %{_libdir}/coq
%{_libdir}/coq/META
%{_libdir}/coq/revision
%dir %{_libdir}/coq/kernel
%dir %{_libdir}/coq/kernel/byterun
%{_libdir}/coq/plugins/micromega/csdpcert
%{_libdir}/coq/tools
%exclude %{_libdir}/coq/tools/CoqMakefile.in
%dir %{_libdir}/coq/user-contrib

%{_mandir}/man1/coq-tex.1%{ext_man}
%{_mandir}/man1/coq_makefile.1%{ext_man}
%{_mandir}/man1/coqc.1%{ext_man}
%{_mandir}/man1/coqchk.1%{ext_man}
%{_mandir}/man1/coqdep.1%{ext_man}
%{_mandir}/man1/coqdoc.1%{ext_man}
%{_mandir}/man1/coqtop.1%{ext_man}
%{_mandir}/man1/coqtop.opt.1%{ext_man}
%{_mandir}/man1/coqwc.1%{ext_man}

%dir %{_datadir}/texmf
%dir %{_datadir}/texmf/tex
%dir %{_datadir}/texmf/tex/latex
%dir %{_datadir}/texmf/tex/latex/misc
%{_datadir}/texmf/tex/latex/misc/coqdoc.sty

%if %{with ide}
%files ide
%{_bindir}/coqide
%{_bindir}/coqidetop
%{_bindir}/coqidetop.opt
%{_mandir}/man1/coqide.1%{ext_man}
%{_datadir}/%{name}
%{_datadir}/applications/coq.desktop
%{_datadir}/icons/hicolor/256x256/apps/coq.png
%{_datadir}/mime/packages/coq.xml
%{_docdir}/%{name}/FAQ-CoqIde
%endif

%files devel -f devel.list
%{_libdir}/coq/tools/CoqMakefile.in

%files doc
%{_docdir}/coq/refman
%{_docdir}/coq/stdlib

%changelog
* Sat Sep  4 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add documentation package based on github.com/coq/doc until we
  can build the documentation directly in OBS.
* Mon Apr 12 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.13.2.
  * Fix crash when using vm_compute on an irreducible PArray.set.
  * Fix crash when loading .vo files containing a vm_compute
    normalized primitive array.
  * Fix Ltac2.Array.init computational complexity.
* Thu Feb 25 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.13.1.
  * Fix arities of VM opcodes for some floating-point operations
    that could cause memory corruption.
* Sun Feb  7 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.13.0.
  * Introduction of primitive persistent arrays in the core
    language, implemented using imperative persistent arrays.
  * Introduction of definitional proof irrelevance for the equality
    type defined in the SProp sort.
  * Cumulative record and inductive type declarations can now
    specify the variance of their universes.
  * Various bugfixes and uniformization of behavior with respect to
    the use of implicit arguments and the handling of existential
    variables in declarations, unification and tactics.
  * New warning for unused variables in catch-all match branches
    that match multiple distinct patterns.
  * New warning for Hint commands outside sections without a
    locality attribute, whose goal is to eventually remove the
    fragile default behavior of importing hints only when using
    Require. The recommended fix is to declare hints as export,
    instead of the current default global, meaning that they are
    imported through Require Import only, not Require.
  * General support for boolean attributes.
  * Many improvements to the handling of notations, including
    number notations, recursive notations and notations with
    bindings. A new algorithm chooses the most precise notation
    available to print an expression, which might introduce changes
    in printing behavior.
  * Tactic improvements in lia and its zify preprocessing step,
    now supporting reasoning on boolean operators such as Z.leb and
    supporting primitive integers Int63.
  * Typing flags can now be specified per-constant / inductive.
  * Improvements to the reference manual including updated syntax
    descriptions that match Coq's grammar in several chapters, and
    splitting parts of the tactics chapter to independent sections.
- Add build flag to turn off building of the IDE.
* Sun Dec 13 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.12.2. Fixes two impacting 8.12 regressions:
  * Fixed a regression causing notations mentioning a coercion to
    be ignored.
  * Fixed a regression causing incomplete inference of implicit
    arguments in exists.
* Tue Nov 17 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.12.1. This contains mostly bug fixes:
  * Polymorphic side-effects inside monomorphic definitions were
    incorrectly handled as not inlined. This allowed deriving an
    inconsistency.
  * Regression in error reporting after SSReflect's case tactic.
    A generic error message "Could not fill dependent hole in
    apply" was reported for any error following case or elim.
  * Several bugs with Search.
  * The details environment introduced in coqdoc in Coq 8.12 can
    now be used as advertised in the reference manual.
  * View menu "Display parentheses" introduced in CoqIDE in
    Coq 8.12 now works correctly.
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Tue Jul 28 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.12.0.
  * New binder notation for non-maximal implicit arguments using []
    allowing to set and see the implicit status of arguments
    immediately.
  * New notation Inductive "I A | x : s := ..." to distinguish the
    uniform from the non-uniform parameters in inductive
    definitions.
  * More robust and expressive treatment of implicit inductive
    parameters in inductive declarations.
  * Improvements in the treatment of implicit arguments and
    partially applied constants in notations, parsing of
    hexadecimal number notation and better handling of scopes and
    coercions for printing.
  * A correct and efficient coercion coherence checking algorithm,
    avoiding spurious or duplicate warnings.
  * An improved Search command which accepts complex queries. This
    takes precedence over the now deprecated ssreflect search.
  * Many additions and improvements of the standard library.
  * Improvements to the reference manual include a more logical
    organization of chapters along with updated syntax descriptions
    that match Coq's grammar in most but not all chapters.
* Sat Jun  6 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.11.2.
  * Fixed a kernel issue where using Require inside a section
    caused an anomaly when closing the section.
  * Fixed normalization in conclusion of custom induction scheme.
  * Fixed a loss of location of some tactic errors.
  * Ignore -native-compiler option when built without native
    compute support.
  * Fixed a segfault issue with CoqIDE completion.
  * Highlighting style is now consistently applied to all three
    buffers of CoqIDE.
* Wed Apr  8 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.11.1, with upstream support for OCaml 4.10.
  * Allow more inductive types in Unset Positivity Checking mode.
  * Fixed bugs in dealing with precedence of notations in custom
    entries.
  * In primitive floats, print a warning when parsing a decimal
    value that is not exactly a binary64 floating-point number.
    For instance, parsing 0.1 will print a warning whereas parsing
    0.5 won't.
  * Fixed an issue in CoqIDE about compiling file paths containing
    spaces.
  * Fixed an issue where Extraction Implicit on the constructor of
    a record was leading to an anomaly.
- Remove now obsolete ocaml-410-build.patch.
* Sun Mar 29 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- The num library is required for OCaml 4.06 or later.
- Add ocaml-410-build.patch: fix build with OCaml 4.10.
* Thu Feb  6 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.11.0.
  * Ltac2, a new tactic language for writing more robust larger
    scale tactics, with built-in support for datatypes and the
    multi-goal tactic monad.
  * Primitive floats are integrated in terms and follow the binary64
    format of the IEEE 754 standard, as specified in the
    Coq.Float.Floats library.
  * Many other cleanups and improvements have been performed and
    are further described in the changelog.
  * Special note on compatibility: Fixed bugs of Export and Import
    that can have a significant impact on user developments.
- Drop unneeded empty *.vos files.
* Sat Nov 30 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.10.2.
  * Fixed a critical bug of template polymorphism and nonlinear
    universes;
  * Fixed a few anomalies;
  * Fixed an 8.10 regression related to the printing of coercions
    associated to notations;
  * Fixed uneven dimensions of CoqIDE panels when window has been
    resized;
  * Fixed queries in CoqIDE.
* Tue Nov 12 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.10.0.
  * some quality-of-life bug fixes;
  * a critical bug fix related to template polymorphism;
  * native 63-bit machine integers;
  * a new sort of definitionally proof-irrelevant propositions: SProp;
  * private universes for opaque polymorphic constants;
  * string notations and numeral notations;
  * a new simplex-based proof engine for the tactics lia, nia, lra
    and nra;
  * new introduction patterns for SSReflect;
  * a tactic to rewrite under binders: under;
  * easy input of non-ASCII symbols in CoqIDE, which now uses GTK3.
- Update to version 8.10.1.
  * Fix proof of False when using SProp
  * Fix an anomaly when unsolved evar in Add Ring
  * Fix Ltac regression in binding free names in uconstr
  * Fix handling of unicode input before space
  * Fix custom extraction of inductives to JSON
- Update version requirements.
* Tue Nov 12 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Fix findlib build dependency.
* Sun Nov  3 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Use memory-constraints package to limit number of threads.
- Add dependencies to fix installation issues.
* Wed Sep 25 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Prevent OOM by limiting the number of threads.
* Tue Sep 24 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Change license tag to LGPL-2.1-only.
- Remove obsolete %%defattr and other spec-cleaner suggestions.
* Sat Aug  3 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 8.9.0.
  * Kernel: mutually recursive records are now supported.
  * Notations:
    + Support for autonomous grammars of terms called “custom
    entries”.
    + Deprecated notations of the standard library will be removed
    in the next version of Coq, see the next subsection for a
    script to ease porting.
    + Added the "Numeral Notation" command for registering decimal
    numeral notations for custom types.
  * Tactics: Introduction tactics intro/intros on a goal that is an
    existential variable now force a refinement of the goal into a
    dependent product rather than failing.
  * Decision procedures: deprecation of tactic romega in favor of
    lia and removal of fourier, replaced by lra which subsumes it.
  * Proof language: focusing bracket { now supports named goals,
    e.g. [x]:{ will focus on a goal (existential variable) named x.
  * SSReflect: the implementation of delayed clear was simplified:
    the variables are always renamed using inaccessible names when
    the clear switch is processed and finally cleared at the end of
    the intro pattern. In addition to that, the use-and-discard
    flag {} typical of rewrite rules can now be also applied to
    views, e.g. => {}/v applies v and then clears v.
    See Section Introduction in the context.
  * Vernacular:
    + Experimental support for attributes on commands, as in
    "#[local] Lemma foo : bar". Tactics and tactic notations now
    support the deprecated attribute.
    + Removed deprecated commands "Arguments Scope" and "Implicit
    Arguments" in favor of "Arguments (scopes)" and "Arguments
    (implicits)".
    + New flag "Uniform Inductive Parameters" to avoid repeating
    uniform parameters in constructor declarations.
    + New commands "Hint Variables" and "Hint Constants" for
    controlling the opacity status of variables and constants in
    hint databases. It is recommended to always use these
    commands after creating a hint database with Create HintDb.
    + Multiple sections with the same name are now allowed.
  * Library: additions and changes in the VectorDef, Ascii, and
    String libraries. Syntax notations are now available only when
    using "Import" of libraries and not merely "Require".
    (Source of incompatibility, see Change Log for details)
  * Toplevels: coqtop and coqide can now display diffs between
    proof steps in color, using the Diffs option.
  * Documentation: we integrated a large number of fixes to the new
    Sphinx documentation.
  * Tools: removed gallina utility and homebrewed Emacs mode.
- Update to version 8.9.1, which contains
  * some quality-of-life bug fixes,
  * many improvements to the documentation,
  * a critical bug fix related to primitive projections and
    native_compute.
- Remove unnecessary dependencies: ncurses-devel is no longer
  needed, and the docs aren't build with TeX and hevea anymore.
- Remove dependencies that are automatically detected.
- Remove icon that is also available from the tarball.
- Replace some identical files by symlinks.
- Fix executable bits and shebangs.
- Separate runtime from devel files by ending.
- Use %%license for LICENSE and CREDITS.
- Be more explicit in %%files.
- Add mime type for Coq source files so they open with the IDE.
- Add rpmlintrc for issues that are hard to fix.
* Thu Oct 11 2018 ptrommler@icloud.com
- update to 8.8.2
* Sun Jan  7 2018 ptrommler@icloud.com
- update to 8.7.1
* Thu Nov  2 2017 ptrommler@icloud.com
- update to 8.7.0
  * I need this in class b/c coq-ide reads _CoqProject files
* Thu Apr 13 2017 peter.trommler@ohm-hochschule.de
- update to 8.6 from upstream
* Fri Dec  2 2016 peter.trommler@ohm-hochschule.de
- update to 8.5pl3 from upstream
* Fri Oct 21 2016 peter.trommler@ohm-hochschule.de
- update to 8.5pl2 from upstream
* Sun Apr 10 2016 peter.trommler@ohm-hochschule.de
- update to 8.5 from upstream
* Sat May 31 2014 peter.trommler@ohm-hochschule.de
- update to 8.4pl4 from upstream
* Sun Jan 12 2014 peter.trommler@ohm-hochschule.de
- update to 8.4pl3 from upstream
- follow upstream versioning
* Sun Nov 10 2013 peter.trommler@ohm-hochschule.de
- revert to our own lablgtk on older systems
  * coq-ide cannot be built using 12.2 lablgtk2
* Wed Nov  6 2013 peter.trommler@ohm-hochschule.de
- use system provided lablgtk2
* Mon Apr  8 2013 peter.trommler@ohm-hochschule.de
- update to 8.4pl2
- coqtop: handle interrupt signals reliably
- restor old behavior for code extraction (AccessOpaque)
* Wed Dec 26 2012 peter.trommler@ohm-hochschule.de
- update to 8.4pl1 from upstream
- dropped f0b93...055.patch (integrated upstream)
- use ocamlfind to find lablgtk2
* Mon Dec  3 2012 peter.trommler@ohm-hochschule.de
- add patch for lablgtk2 v 2.16
* Thu Nov 29 2012 peter.trommler@ohm-hochschule.de
- mark config file
* Sun Nov 11 2012 peter.trommler@ohm-hochschule.de
- give up on old ocaml names and require ocaml-lablgtk2-devel
- clean up spec file
* Thu Oct 18 2012 peter.trommler@ohm-hochschule.de
- remove requires and rely on automatic dependency generation
  for ocaml
* Wed Oct 17 2012 peter.trommler@ohm-hochschule.de
- packaged new file coq.png
* Sun Oct  7 2012 peter.trommler@ohm-hochschule.de
- update to 8.4 from upstream
* Thu Apr 12 2012 peter.trommler@ohm-hochschule.de
- add ocaml- prefix to lablgtk-devel Buildrequires
* Wed Apr 11 2012 peter.trommler@ohm-hochschule.de
- add Buildrequires hevea needed for documentation
* Wed Apr 11 2012 peter.trommler@ohm-hochschule.de
- cleaned up spec file (BuildRequires and Requires one each line)
- SPDX license tag
* Wed Apr 11 2012 peter.trommler@ohm-hochschule.de
- upgraded to 8.3pl4 from upstream
  Bug fixes:
- #2724 (using notations with binders in cases patterns was provoking an anomaly)
- #2723 (alpha-conversion bug #2723 introduced in r12485-12486)
- #2732 (anomaly when using the tolerance for writing "f atomic_tac"
    as a short-hand for "f ltac:(atomic_tac)")
- #2729 (vm_compute: function used to decompose constructors did not handle let-ins)
- #2728 (compatibility with camlp5 6.05)
- #2682 (Fail discard the effects of a successful command)
- #2703 (Undetected universe inconsistency)
- #2667 (Coq crashes when "Arguments Scope" has too many parameters)
- Compilation of coqide under MacOS with gtk >= 2.24.11
- Coqdoc: Fixing missing newline when using "Proof term."
